The Image Helper
================

The plugin comes with an Image helper that makes it easy to display the images generated by the ImageStorage model and the events that process the images.

This helper is the best added to your ```AppController```.

```php
class AppController extends Controller {
	$helpers = array(
		'FileStorage.Image'
	);
}
````

In your views you can now access all your image versions, which you have declared before in your config, through the helper.

```php
echo $this->Image->display($product['Image'], 'small');
```

You have to pass the file storage record array without the alias, just passing `$product` in the above example would be wrong, the helper won't find the field it is looking for then. In the case of a [hasMany](http://book.cakephp.org/2.0/en/models/associations-linking-models-together.html#hasmany) or [HABTM](http://book.cakephp.org/2.0/en/models/associations-linking-models-together.html#hasandbelongstomany-habtm) association you'll have to do it this way because the data structure that CakePHP returns for them is different:

```php
foreach ($product['Image'] as $image) {
    echo $this->Image->display($image);
}
```

If you want to get only the URL to an image you can call ```imageUrl()```.

```php
$imageUrl = $this->Image->imageUrl($product['Image'], 'small');
echo $this->Html->image($imageUrl);
```

Options for display() and imageUrl()
------------------------------------

The third argument of both methods is an option array, right now it has only one option to set.

* **image:** The image data array, for `example $product['Image']`.
* **version:** Optional, image version string. If not defined the helper will use the original image, not a version.
* **fallback:** Optional, can be `boolean` true or `string`. If boolean true it will use ```placeholder/<YOUR-VERSION>.jpg``` as place  holder. If string it will use that string as image.
